unit Main;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Buttons, ComCtrls, ExtCtrls, iDragDrop;

type
  TForm1 = class(TForm)
    Page: TPageControl;
    TabSheet1: TTabSheet;
    TabSheet2: TTabSheet;
    TrkLevel: TTrackBar;
    LblLevel: TLabel;
    ChkBackup: TCheckBox;
    ChkNoExpo: TCheckBox;
    ChkNoIcon: TCheckBox;
    TabSheet3: TTabSheet;
    edtUpxPath: TEdit;
    Label1: TLabel;
    BitBtn4: TBitBtn;
    BitBtn5: TBitBtn;
    BitBtn6: TBitBtn;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure BitBtn4Click(Sender: TObject);
    procedure BitBtn5Click(Sender: TObject);
    procedure BitBtn6Click(Sender: TObject);
    procedure TrkLevelChange(Sender: TObject);
  private
    Dropper     : TShellDrop;

    FStdOut, FErrOut: TStringList;
    procedure   ClearOut();
    procedure   ShowOut();

    procedure   DroppedAction(AFiles, AFolds: TStringList;
                            AControl: TControl; APos: TPoint);
    procedure   DoLevelCompress(const Path: string);
    procedure   DoBestCompress(const Path: string);
    procedure   DoDeCompress(const Path: string);
  public

  end;

var
  Form1: TForm1;

implementation

uses
    GrabConsole, fjutil;

{$R *.dfm}

//------------------------------------------------------------------------------
//  RXgN^
procedure TForm1.FormCreate(Sender: TObject);
begin
    FStdOut := TStringList.Create;
    FErrOut := TStringList.Create;

    Dropper := TShellDrop.Create(Page, DroppedAction);
    Dropper.Start();
end;

//------------------------------------------------------------------------------
//  fXgN^
procedure TForm1.FormDestroy(Sender: TObject);
begin
    Dropper.Free;

    FStdOut.Free;
    FErrOut.Free;
end;

//------------------------------------------------------------------------------
//  ƗpXgNA
procedure   TForm1.ClearOut();
begin
    FStdOut.Clear;
    FErrOut.Clear;
end;

//------------------------------------------------------------------------------
//  \
procedure   TForm1.ShowOut();
begin
    if FStdOut.Count > 0 then MBox.InfoOk(FStdOut.Text, true);
    if FErrOut.Count > 0 then MBox.ErrorOk(FStdOut.Text, true);
end;

//------------------------------------------------------------------------------
//  t@Chbv
procedure   TForm1.DroppedAction(AFiles, AFolds: TStringList;
            AControl: TControl; APos: TPoint);
var
    i: integer;
begin
    Screen.Cursor := crHourGlass;
    ClearOut();

    for i := 0 to AFiles.Count - 1 do
    begin
        if (AnsiPos(UpperCase(ExtractFileExt(AFiles[i])), '.EXE,.DLL') = 0) then continue;
        if (Page.ActivePageIndex = 0) then
        begin
            if (TrkLevel.Position = 10) then DoBestCompress(AFiles[i])
                                        else DoLevelCompress(AFiles[i]);
        end
        else
        if (Page.ActivePageIndex = 1) then
        begin
            DoDeCompress(AFiles[i]);
        end;
    end;

    ShowOut();
    Screen.Cursor := crDefault;
end;

//------------------------------------------------------------------------------
//  wv
procedure TForm1.BitBtn4Click(Sender: TObject);
begin
    ClearOut();
    PipeConsole(edtUpxPath.Text, FStdOut, FErrOut);
    ShowOut();
end;

//------------------------------------------------------------------------------
//  LICENSE
procedure TForm1.BitBtn5Click(Sender: TObject);
begin
    ClearOut();
    PipeConsole(edtUpxPath.Text + ' -L', FStdOut, FErrOut);
    ShowOut();
end;

//------------------------------------------------------------------------------
//  VERSION
procedure TForm1.BitBtn6Click(Sender: TObject);
begin
    ClearOut();
    PipeConsole(edtUpxPath.Text + ' -V', FStdOut, FErrOut);
    ShowOut();
end;

//------------------------------------------------------------------------------
//  kxύX
procedure TForm1.TrkLevelChange(Sender: TObject);
const
    LEVEL_STR: array[0..10] of string
    = ('none: ܂k',
       '1   : ΂₭k', '2   : ΂₭k', '3   : ΂₭k',
       '4   : ĂǂɈk', '5   : ĂǂɈk', '6   : ĂǂɈk',
       '7   : 舳k', '8   : 舳k', '9   : 舳k',
       'best: 舳k'
    );
begin
    LblLevel.Caption := LEVEL_STR[TrkLevel.Position];
end;

//------------------------------------------------------------------------------
//  k
const
    BACK_CMD : array[Boolean] of string = ('', '-k');
    EXPO_CMD : array[Boolean] of string = ('', '--compress-exports=0') ;
    ICON_CMD : array[Boolean] of string = ('', '--compress-icons=0');

procedure   TForm1.DoLevelCompress(const Path: string);
const
    LEVEL_CMD: array[0..9] of string = ('', '-1', '-2', '-3', '-4', '-5', '-6', '-7', '-8', '-9');
    COMMAND_FMT: string = '%s %s %s %s %s %s';
var
    Level: integer;
    Line: string;
begin
    Level := TrkLevel.Position;
    //  xw舳k
    if (-1 < Level) and (Level < 10) then
    begin
        Line := Format(COMMAND_FMT, [
                            edtUpxPath.Text,                //  UPXpX
                            LEVEL_CMD[Level],               //  k
                            BACK_CMD[ChkBackup.Checked],    //  obNAbv
                            EXPO_CMD[ChkNoExpo.Checked],    //  GNX|[gk
                            ICON_CMD[ChkNoIcon.Checked],    //  ACRk
                            Path
        ]);
//        ClearOut();
        PipeConsole(Line, FStdOut, FErrOut);
//        ShowOut();
    end
end;

//------------------------------------------------------------------------------
//  xXgk
procedure   TForm1.DoBestCompress(const Path: string);
const
    BEST_CMD : array[0..1] of string = (
        '%s --best --crp-ms=999999 --nrv2b -o result_2b.exe %s %s %s %s',
        '%s --best --crp-ms=999999 --nrv2d -o result_2d.exe %s %s %s %s'
    );
var
    Line: string;
begin
//    ClearOut();
    Line := Format(BEST_CMD[0], [
                        edtUpxPath.Text,                //  UPXpX
                        BACK_CMD[ChkBackup.Checked],    //  obNAbv
                        EXPO_CMD[ChkNoExpo.Checked],    //  GNX|[gk
                        ICON_CMD[ChkNoIcon.Checked],    //  ACRk
                        Path
    ]);
    PipeConsole(Line, FStdOut, FErrOut);
    Line := Format(BEST_CMD[1], [
                        edtUpxPath.Text,                //  UPXpX
                        BACK_CMD[ChkBackup.Checked],    //  obNAbv
                        EXPO_CMD[ChkNoExpo.Checked],    //  GNX|[gk
                        ICON_CMD[ChkNoIcon.Checked],    //  ACRk
                        Path
    ]);
    PipeConsole(Line, FStdOut, FErrOut);
//    ShowOut();
end;

//------------------------------------------------------------------------------
//  
procedure   TForm1.DoDeCompress(const Path: string);
var
    Line: string;
begin
    Line := Format('%s -d %s', [edtUpxPath.Text, Path]);
//    ClearOut();
    PipeConsole(Line, FStdOut, FErrOut);
//    ShowOut();
end;

end.

